function [iota,rho,lambda,V,xmax,prof,ms,prices,prodsur,conssur,expfreq, ...
    tildes,cond_num] = compOE(outfile,constants,transition,profpar,control,initial)
% INPUTS:   - output file, constants,transition,profpar, control, and initial parameters
%           
% OUTPUTS:  - OE investment strategy iota and exit strategy rho (xmax x 1)
%           - OE entry rate lambda
%           - OE value function V (xmax x 1)
%           - xmax: max acheivable state determined endogenously
%           - OE profits: prof,ms,prices,prodsur,conssur (xmax x 1)
%           - expfreq (xmax x 1): expected number of visits
%             to each state by one firm under OE strats.
%           - tildes(xmax x 1): OE expected state
%           - cond_num: condition number matrix inversion for expfreq
%
% Computes OE in entry/exit case


% DEFAULT initial conditions
xmax=initial.xmax0;
lambda1=initial.lambda10;
lambda2=initial.lambda20;
iota=initial.iota0;
rho=initial.rho0;

% SET YOUR OWN INITIAL CONDITIONS
%xmax=;
%lambda1=;
%lambda2=;
%iota=;
%rho=;

% Rename parameters to be used in this function
% to simplify notation
beta=constants.beta;
kappa=constants.kappa;
xe=constants.xe;
FACTOR_lambda=control.FACTOR_lambda;
FACTOR_lambdaignore=control.FACTOR_lambdaignore;
TOL_zeroprof=control.TOL_zeroprof;

% First, find OE ignoring the presence of "my" firm when computing profits
% ignore=1. In this way only need to compute profits once
% Then compute "exact" one period profit function (ignore=2)
            
for ignore=1:2
  if (ignore==2) 
      fprintf(outfile,'...Recomputing with actual (not approximated) profit function.\n');
  end
    % Check if OE is in initial interval [lamdba1,lambda2]           
    % Check lambda1
    iter_lambdal=1;
    iter_lambdar=1;
    while(iter_lambdal)
        fprintf(outfile,'OE calculations for entry rate %f, range (%f,%f), xmax %f.\n',lambda1,lambda1,lambda2,xmax);
        [iota,rho,xmax,V,prof,ms,prices,prodsur,conssur,expfreq, ...
        tildes,cond_num] = fpstratxmax(constants,transition,profpar, ...
        control,lambda1,iota,rho,xmax,ignore);
        if(beta*V(xe)-kappa<0)
            fprintf(outfile,'Extending left endpoint of interval entry rate at %f \n',lambda1);
            lambda2=lambda1;
            lambda1=lambda2*(1-FACTOR_lambda);
            iter_lambdar=0;
        else
            iter_lambdal=0;
        end
    end
    % Check lambda2
    while(iter_lambdar)
        fprintf(outfile,'OE calculations for entry rate %f, range (%f,%f), xmax %f.\n',lambda2,lambda1,lambda2,xmax);
        [iota,rho,xmax,V,prof,ms,prices,prodsur,conssur,expfreq, ...
        tildes,cond_num] = fpstratxmax(constants,transition,profpar, ...
        control,lambda2,iota,rho,xmax,ignore); 
        if(beta*V(xe)-kappa>0)
            fprintf(outfile,'Extending right endpoint of interval entry rate at %f \n',lambda2);
            lambda1=lambda2;
            lambda2=lambda1*(1+FACTOR_lambda); 
        else
            iter_lambdar=0;
        end
    end

    % Bisection method to find OE (satisfy zero profit function)
    V(xe)=100*(TOL_zeroprof+kappa)/beta ;
    while(abs(beta*V(xe)-kappa)>TOL_zeroprof)
        lambda=(lambda1+lambda2)/2;
        fprintf(outfile,'OE calculations for entry rate %f, range (%f,%f), xmax %f.\n',lambda,lambda1,lambda2,xmax);
        [iota,rho,xmax,V,prof,ms,prices,prodsur,conssur,expfreq, ...
        tildes,cond_num] = fpstratxmax(constants,transition,profpar, ...
        control,lambda,iota,rho,xmax,ignore); 
        if(beta*V(xe)-kappa>=0)
            lambda1=lambda;
        else
            lambda2=lambda;
        end
    end
    lambda1=lambda*(1-FACTOR_lambdaignore);
    lambda2=lambda*(1+FACTOR_lambdaignore);
end
    
    
    
    
    
    
    
    
