function [iota,rho,lambda,V,xmax,prof,ms,prices,prodsur,conssur,invdistr, ...
    tildes,cond_num] = compOE_fixn(outfile,constants,transition,profpar,control,initial)
% INPUTS:   - output file,constants,transition,profpar, control, and initial parameters
%           
% OUTPUTS:  - OE investment strategy iota and exit strategy rho (xmax x 1)
%           - lambda: number of firms 
%           - OE value function V (xmax x 1)
%           - xmax: max acheivable state determined endogenously
%           - OE profits: prof,ms,prices,prodsur,conssur (xmax x 1)
%           - invdistr (xmax x 1): invariant distr. of Markov chain that 
%             describes evolution of one firm under OE strats   
%           - tildes(xmax x 1): OE expected state
%           - cond_num: condition number matrix inversion for invdistr
%
% Computes OE in no entry/no exit case

% DEFAULT initial conditions
xmax=initial.xmax0;
iota=initial.iota0;
rho=initial.rho0;

% SET YOUR OWN INITIAL CONDITIONS
%xmax=;
%iota=;
%rho=;

num_firms=constants.fix_n-1; % num_firms=number of firms in tilde s (competitors' state)
                             % need to substract "my firm"
lambda=constants.fix_n;

% First, find OE ignoring the presence of "my" firm when computing profits
% ignore=1. In this way only need to compute profits once
% Then compute "exact" one period profit function (ignore=2)
            
for ignore=1:2
    if (ignore==2) fprintf(outfile,'...Recomputing with actual (not approximated) profit function.\n');
    end
    [iota,rho,xmax,V,prof,ms,prices,prodsur,conssur,invdistr, ...
    tildes,cond_num] = fpstratxmax(constants,transition,profpar, ...
    control,num_firms,iota,rho,xmax,ignore); 
end
    
