function [prof,ms,prices,prodsur,conssur] = comp_prof(profpar,state,xmax,ignore)

% INPUTS:   - profit parameters profpar
%           - state (xmax x 1)
%           - xmax 
%           - variable ignore: ignore=1 if the presence of "my" firm is 
%             ignored when computing profits. In this way only 
%             need to compute profits once 
% OUTPUTS:  - profit function prof (xmax x 1)
%           - market shares ms (xmax x 1)
%           - prices (xmax x 1)
%           - producer surplus prodsur (xmax x 1)
%           - consumer surplus conssur (xmax x 1)
% 
% Calls function profit


% Rename parameters to be used in this function
% to simplify notation
p0=profpar.p0*ones(xmax,1);

if(ignore==1)
    [prof,ms,prices,prodsur,conssur]=profit(profpar,state,p0);  
    prodsur=prodsur*ones(xmax,1);        % if ignore=1, producer and consumer surplus 
    conssur=conssur*ones(xmax,1);        % same for all states 
else
    pini=p0;    
    Ident=eye(xmax);
    prof=zeros(xmax,1);    ms=zeros(xmax,1); 
    prices=zeros(xmax,1);  
    prodsur=zeros(xmax,1);  conssur=zeros(xmax,1);
    for i=1:xmax  
        [profaux,msaux,pricesaux,prodsur(i),conssur(i)]=...
            profit(profpar,state+Ident(:,i),pini); 
        prof(i)=profaux(i);
        ms(i)=msaux(i);
        prices(i)=pricesaux(i);
        pini=pricesaux;
    end  
end  
    