function [expfreq, tildes, cond_num] = expstate(constants,control,B,lambda,xmax)

% INPUTS:   - constants and control parameters
%           - matrix of continutaion and transition probs. B (xmax x xmax)
%           - entry rate lambda
%           - xmax 
% OUPUTS:   - if fix_n=0 (entry/exit) expfreq (xmax x 1) is expected 
%             number of visits to each state by one firm 
%             if fix_n ~=0 (no entry/no exit) expfreq is invariant distr.
%             of Markov chain that describes evolution of one firm
%           - expected state tildes associated to B and lambda (xmax x 1)
%           - condition number of matrix (I-B) cond_num


% Rename parameters to be used in this function
% to simplify notation
beta=constants.beta;
xe=constants.xe;
fix_n=constants.fix_n;
TOL_condnum=control.TOL_condnum;
TOL_freq=control.TOL_freq;

if(fix_n==0)   % entry/exit
    cond_num=rcond(eye(xmax)-B);

    if(cond_num>TOL_condnum)  
        Freq=(eye(xmax)-B)\eye(xmax);   % if matrix is not ill conditioned, compute inverse
    else  
        fprintf('Ill-conditioned matrix for entry rate %f \n',lambda)
        % if matrix is ill-conditioned, compute infinite sum.   
        r=(1/beta-1)*100;       % interest rate
        num_pers=5*TOL_freq/r;  % number of periods to sum: proportional to interest rate
        cumB=eye(xmax);
        Freq=eye(xmax);   
        for i=1:num_pers
            cumB=cumB*B;
            Freq=Freq + cumB;  
        end
    end
    expfreq=transpose(Freq(xe,:));   % exp. number of visits to each state starting at xe

else    % no entry/no exit: compute invariant distr.
    A=transpose(B)-eye(xmax);
    A(xmax,:)=ones(1,xmax);
    rhs=zeros(xmax,1);
    rhs(xmax)=1;
    expfreq=A\rhs;   
    cond_num=rcond(A);
end

tildes=lambda*expfreq;    % expected state 
