function [iotaout,rhoout,xmaxout,Vout,prof,ms,prices,prodsur,conssur,expfreq, ...
    tildes, cond_num] = fpstratxmax(constants,transition,profpar, ...
    control,lambda,iota,rho,xmax,ignore)
% INPUTS:   - constants,transition,profpar, and control parameters
%           - entry rate lambda 
%           - initial investment strategy iota (xmax x 1)
%           - initial exit strategy rho (xmax x 1)
%           - initial value xmax 
%           - variable ignore: ignore=1 if the presence of "my" firm is 
%             ignored when computing profits. In this way only 
%             need to compute profits once 
% OUTPUTS:  - investment strategy iotaout and exit strategy rhoout (xmax x 1)
%             which is fixed point given entry rate lambda
%           - xmaxout: max acheivable state determined endogenously
%           - value function Vout associated to fixed point (xmax x 1)
%           - profits assocciated to fixed point:
%             prof,ms,prices,prodsur,conssur (xmax x 1)
%           - expfreq (xmax x 1): if entry and exit, expected number of visits
%             to each state by one firm under fixed point strats.
%             if no entry/no exit, invariant distr.
%             of Markov chain that describes evolution of one firm    
%           - tildes: expected state under fixed point strats. (xmax x 1)
%           - cond_num: condition number matrix inversion for expfreq

% Rename parameters to be used in this function
% to simplify notation
TOL_freqxmax=control.TOL_freqxmax;
xmaxupdate=control.xmaxupdate;    

condxmax=1;

while(condxmax)
    [iotaout,rhoout,Vout,prof,ms,prices,prodsur,conssur,expfreq, ...
    tildes, cond_num] = fpstrat(constants,transition,profpar, ...
    control,lambda,iota,rho,xmax,ignore);
    if(expfreq(xmax)>TOL_freqxmax)
        xmaxout=xmax+xmaxupdate;
        iotaout(xmax+1:xmaxout)=iotaout(xmax);
        rhoout(xmax+1:xmaxout)=rhoout(xmax);
        xmax=xmaxout;
        iota=iotaout;
        rho=rhoout;
    else 
        condxmax=0;
        xmaxout=xmax;
    end
end


