function [prof,ms,prices,prodsur,conssur] = profit(profpar,state,p0)

% INPUTS:   - profit parameters profpar
%           - state (xmax x 1)
%           - initial condition for pricing game p0 (xmax x 1)
% OUTPUTS:  - profit function prof (xmax x 1)
%           - market shares ms (xmax x 1)
%           - prices (xmax x 1)
%           - producer surplus prodsur (scalar)
%           - consumer surplus conssur (scalar)
% 
% Profit function in Weintraub, Benkard, and Van Roy (2005)
% price competition with product differentiation
% logit demand system
% constant marginal cost of production
% Calls function focprice which are first order conditions of pricing game
% The i'th component of vectors prof,ms, and prices, 
% are the profit, market share, and price, respectively, 
% that a firm in state i would receive (if there was one in that state).

% Rename parameters to be used in this function
% to simplify notation
m=profpar.m;
Y=profpar.Y;
theta1=profpar.theta1;
theta2=profpar.theta2;
psi=profpar.psi;
c=profpar.c;
utout=profpar.utout;

w=transpose([0:1:size(state,1)-1])/psi+1;

% Solve pricing game
options=optimset('Display', 'off');
[prices,fevalp,flag]=fsolve(@focprice,p0,options,profpar,state,w);
if(flag<=0)
    warning('Could not solve for one period profits equilibrium.');
end    

prices=real(prices);
n =exp(theta1*log(w)+theta2*log(Y-prices));
denom = exp(utout) + n'*state;   
ms = n/denom;
prodsur=m*sum(state.*ms.*(prices-c));       
conssur=m*log(denom);                
prof=m*(prices-c).*ms;

%prices=real(p0);
%n =exp(theta1*log(w)+theta2*log(Y-p0));
%denom = exp(utout) + n'*state;   n
%ms = n/denom;
%prodsur=m*sum(state.*ms.*(p0-c));       
%conssur=m*log(denom);                
%prof=m*(p0-c).*ms;

